
from formant.sdk.cloud.v2.formant_admin_api_client.models import TaskSummaryMetadata, DeviceOfflineEventTags, EventSeekQueryTypesItem, DatapointEventType, CommandDeliveryEventTags, TaskSummaryType, FocusedDatapoint, DeviceOnlineEventTags, InterventionRequestInterventionType, TaskSummaryStreamType, EventQuerySeveritiesItem, AnnotationStreamType, StatefulEventTags, TaskSummary, TeleopSessionRecordTags, DeviceOnlineEvent, Label, CustomEventTags, EventSortColumn, EventExportSheetResult, StatefulEventMetadata, TeleopSessionRecordType, DeviceOnlineEventSeverity, EventSort, AnnotationMetadata, CommandDeliveryEventStreamType, EventSortOrder, TaskSummaryTags, InterventionRequestTags, SystemEventType, EventSeekQuery, EventFilter, EventFilterEventTypesItem, EventExportSheetRequest, PortForwardingSessionRecordStreamType, CustomEventStreamType, SelectionRequestData, DeviceOfflineEventMetadata, InterventionRequestType, CommandDeliveryEventMetadata, PhysicalRequestData, CustomEventMetadata, EventListResponse, SystemEventTags, InterventionRequestSeverity, LabelingRequestData, DeviceOfflineEvent, DatapointEventSeverity, InterventionRequestMetadata, EventTriggerCommand, DatapointEventStreamType, CommentStreamType, DeviceOnlineEventType, DeviceOfflineEventSeverity, StatefulEventStreamType, InterventionRequest, Comment, CustomEventSeverity, PortForwardingSessionRecordMetadata, StatefulEventType, TeleopSessionRecordStreamType, EventSeekQueryDirection, CustomEvent, EventHistogramEntry, DeviceOfflineEventStreamType, EventSeekQuerySeveritiesItem, CommandDeliveryEvent, DatapointEventMetadata, TeleopSessionRecordMetadata, EventSeekQueryEventTypesItem, TeleopSessionRecord, DeviceOfflineEventType, SystemEventMetadata, SystemEventStreamType, LabeledPolygon, EventFilterSeveritiesItem, PortForwardingSessionRecord, DeviceOnlineEventMetadata, AnnotationType, CommentMetadata, DatapointEvent, TeleopRequestData, SystemEvent, StatefulEventSeverity, AnnotationTags, StatefulEvent, EventCounts, Annotation, DeviceOnlineEventStreamType, CommandDeliveryEventType, EventHistogram, DatapointEventTags, CommentTags, EventQueryEventTypesItem, CustomEventType, PortForwardingSessionRecordType, EventQueryTypesItem, EventFilterTypesItem, PortForwardingSessionRecordTags, CommentType, InterventionRequestStreamType, EventQuery, TaskSummaryReport
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationFieldValuesRequestTags, AnnotationFieldValuesRequest, AnnotationMetadata, ScopeFilterTypesItem, AnnotationType, UserParametersRolesItem, FocusedDatapoint, AnnotationTags, ScopeFilter, AnnotationTemplateTags, Annotation, AnnotationTemplate, TagParameters, AnnotationStreamType, SheetParameters, AnnotationField, AnnotationFieldValuesResponse, AnnotationFieldType, AnnotationFieldValue, AnnotationFieldValueTags, AnnotationTemplateListResponse, UserParameters
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_query_api_client.models import File, VideoMimeType, Image, StreamDataType, Odometry, Localization, QueryAggregate, StreamData, Health,HealthStatus, Vector3, Quaternion, StreamDataPointsItem, QueryTypesItem, NumericSetEntry, PointCloud, Twist, StreamAggregateDataTags, Map, Transform, Bitset, ImageAnnotation, Battery, StreamDataTags, BoundingBox, StreamAggregateDataType, Query, StreamAggregateData, Video, TransformNode, Health, Video,VideoMimeType, StreamDataListResponse, Location, Goal, Path, HealthStatus
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *




from formant.sdk.cloud.v2.formant_admin_api_client.models import BitsetViewConfiguration, Vector3, Camera, ImageViewConfigurationMode, PointCloudViewConfiguration, ImageViewConfiguration, TransformTreeViewConfiguration, ViewConfiguration, ViewTags, Filter, ViewListResponse, View, LocationViewConfigurationBasemap, PartialViewLayoutType, Location, LocationViewConfiguration, LocalizationViewConfiguration, ViewLayoutType, NumericViewConfiguration, PartialView, PartialViewTags, ViewConfigurationType, LocationViewport
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

T = TypeVar("T", bound="LastSeenResponse")


@attr.s(auto_attribs=True)
class LastSeenResponse:
    """
    Attributes:
        organization_id (str):
        device_id (str):
        time (datetime.datetime):
    """

    organization_id: str
    device_id: str
    time: datetime.datetime
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id = self.organization_id
        device_id = self.device_id
        time = self.time.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "organizationId": organization_id,
                "deviceId": device_id,
                "time": time,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        organization_id = d.pop("organizationId")

        device_id = d.pop("deviceId")

        time = isoparse(d.pop("time"))

        last_seen_response = cls(
            organization_id=organization_id,
            device_id=device_id,
            time=time,
        )

        last_seen_response.additional_properties = d
        return last_seen_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOfflineEventTags, RtcInfoRtcIceServerProtocol, TeleopJoystickConfigurationPosition, DeviceStreamDirectoryWatchConfigurationType, DeviceTeleopHardwareStreamConfiguration, DeviceConfigurationTemplateTags, DeviceOnlineEventTags, TeleopJoystickAxisConfigurationDimension, DeviceConfigurationTemplateListResponse, DeviceTeleopCustomStreamConfigurationMode, DeviceStreamRosTopicConfigurationRosVersion, DeviceConfiguration, DeviceConfigurationDocumentTags, DeviceTeleopHardwareStreamConfigurationMode, TeleopViewConfiguration, DeviceTeleopRosStreamConfigurationTopicType, DeviceQuery, DeviceDetails, DeviceDetailsListResponse, OnDemandPresenceStreamItemGroup, DeviceOnlineEvent, DeviceTags, DeviceStreamRosTransformTreeConfiguration, OnDemandStreamPresence, VideoDevice, DeviceStateEnv, DeviceStreamFileTailConfigurationFileFormat, DeviceConfigurationTemplate, DeviceDetailsSort, DeviceReportedConfigurationState, DeviceDiagnosticsConfiguration, DeviceOnlineEventSeverity, DeviceRosConfiguration, PartialDeviceTags, DeviceTeleopRosStreamConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceTeleopRosStreamConfigurationAudioCodec, OnDemandPresenceTimeRange, DeviceStreamRosLocalizationConfigurationType, DeviceStreamHardwareConfigurationQuality, DeviceStreamConfiguration, DeviceStreamRosTopicConfiguration, KernelInfo, DeviceStreamCustomConfigurationType, DeviceProvisioningRequest, DeviceOfflineEventMetadata, DeviceStreamRosLocalizationConfiguration, DeviceDetailsType, Network, DeviceStreamTransformConfiguration, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceScope, DeviceTeleopRosStreamConfigurationMode, DeviceRosState, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceStreamCustomConfiguration, OnDemandState, DeviceStreamConfigurationTags, OnDemandBufferBufferType, DeviceOfflineEvent, DeviceTeleopHardwareStreamConfigurationQuality, DeviceStreamHardwareConfiguration, DeviceFollower, DeviceApplicationConfiguration, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceState, DeviceRealtimeConfiguration, DeviceStreamFileTailConfigurationType, DeviceTeleopHardwareStreamConfigurationHardwareType, NetworkInfo, DeviceDiskConfiguration, DeviceProvisioning, DeviceTeleopConfiguration, DeviceOnlineEventType, DeviceStreamDirectoryWatchConfigurationFileType, DeviceOfflineEventSeverity, DevicePortForwardingConfiguration, DeviceStreamHardwareConfigurationType, TeleopJoystickConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceStreamConfigurationQuality, DeviceDetailsTags, DeviceTeleopRosStreamConfigurationQuality, AdapterConfiguration, DeviceQueryType, DeviceBlobData, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceScopeTypesItem, DeviceOfflineEventStreamType, DeviceCredentials, RosTopic, ValidationConfiguration, DeviceResourcesConfiguration, DeviceStreamDirectoryWatchConfiguration, DeviceType, DeviceStreamHardwareConfigurationHardwareType, DeviceOfflineEventType, HwInfo, DeviceTelemetryConfiguration, AudioDevice, DeviceConfigurationDocument, DeviceStreamRosTransformTreeConfigurationType, PartialDeviceType, OnDemandPresenceStreamItemGroupDatapointType, DeviceDetailsSortColumn, ScopeFilterTypesItem, DeviceOnlineEventMetadata, CommandProgress, DeviceTeleopCustomStreamConfigurationRtcStreamType, DeviceStreamRosLocalizationConfigurationRosVersion, RtcInfoRtcIceTransportPoliciesItem, DeviceListResponse, ScopeFilter, PartialDevice, DeviceOnlineEventStreamType, DeviceStreamRosTopicConfigurationType, OnvifDevice, Device, DeviceTeleopCustomStreamConfiguration, DeviceStreamFileTailConfiguration, DeviceApplicationConfigurationConfigurationMap, TeleopJoystickAxisConfiguration, DeviceDetailsSortOrder, RtcInfo, NodeInfo, OnDemandBuffer, OsInfo
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional




from formant.sdk.cloud.v2.formant_admin_api_client.models import FileInfo, CommandStreamType, CommandParameterMeta, CommandRequest, CommandDeliveryEventStreamType, CommandTemplateTags, CommandResponseTags, ScopeFilterTypesItem, CommandProgress, CommandDeliveryEventTags, CommandTemplateListResponse, CommandTags, CommandTemplate, CommandResponseStreamType, ScopeFilter, CommandRequestListResponse, CommandDeliveryEventType, CommandDeliveryEventMetadata, CommandQuery, CommandResponse, CommandListResponse, Command, Filter, CommandDeliveryEvent, CommandTemplateParameterMeta, CommandParameter
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
